@@ -124,8 +124,6 @@ func (gui *Gui) createAllViews() error {
 		return err
 	}
 
-	gui.GitCommand.GetCmdWriter = gui.getCmdWriter
-
 	return nil
 }
 
@@ -374,7 +372,7 @@ func (gui *Gui) onInitialViewsCreation() error {
 		return err
 	}
 
-	if !gui.Config.GetUserConfig().DisableStartupPopups {
+	if !gui.UserConfig.DisableStartupPopups {
 		popupTasks := []func(chan struct{}) error{}
 		storedPopupVersion := gui.Config.GetAppState().StartupPopupVersion
 		if storedPopupVersion < StartupPopupVersion {
