@@ -109,8 +109,7 @@ func chineseTranslationSet() TranslationSet {
 		Squash:                              "压缩",
 		LcPickCommit:                        "选择提交（变基过程中）",
 		LcRevertCommit:                      "还原提交",
-		OnlyRenameTopCommit:                 "只能从 lazygit 内部重写最高的提交。请使用 shift-R",
-		LcRenameCommit:                      "改写提交",
+		LcRewordCommit:                      "改写提交",
 		LcDeleteCommit:                      "删除提交",
 		LcMoveDownCommit:                    "下移提交",
 		LcMoveUpCommit:                      "上移提交",
@@ -135,7 +134,6 @@ func chineseTranslationSet() TranslationSet {
 		SurePopStashEntry:                   "您确定要应用并删除此贮藏条目吗？",
 		StashApply:                          "应用贮藏",
 		SureApplyStashEntry:                 "您确定要应用此贮藏条目？",
-		NoStashTo:                           "没有贮藏条目可以 {{.method}}",
 		NoTrackedStagedFilesStash:           "没有可以贮藏的已跟踪/暂存文件",
 		StashChanges:                        "贮藏更改",
 		MergeAborted:                        "合并中止",
@@ -441,8 +439,7 @@ func chineseTranslationSet() TranslationSet {
 		LcCreatePullRequestOptions:          "创建抓取请求选项",
 		LcDefaultBranch:                     "默认分支",
 		LcSelectBranch:                      "选择分支",
-		CreatingPullRequestAtUrl:            "在 URL 创建抓取请求: %s",
-		Spans: Spans{
+		Actions: Actions{
 			// TODO: combine this with the original keybinding descriptions (those are all in lowercase atm)
 			CheckoutCommit:                    "检出提交",
 			CheckoutReflogCommit:              "检出reflog提交",
