@@ -50,11 +50,11 @@ func dutchTranslationSet() TranslationSet {
 		SureForceCheckout:                   "Weet je zeker dat je het uitchecken wil forceren? Al je lokale verandering zullen worden verwijdert",
 		ForceCheckoutBranch:                 "Forceer uitchecken op deze branch",
 		BranchName:                          "Branch naam",
-		NewBranchNameBranchOff:              "Nieuw branch naam (Branch is afgeleid van {{.branchName}})",
+		NewBranchNameBranchOff:              "Nieuw branch naam (Branch is afgeleid van '{{.branchName}}')",
 		CantDeleteCheckOutBranch:            "Je kan een uitgecheckte branch niet verwijderen!",
 		DeleteBranch:                        "Verwijder branch",
-		DeleteBranchMessage:                 "Weet je zeker dat je branch {{.selectedBranchName}} wilt verwijderen?",
-		ForceDeleteBranchMessage:            "Weet je zeker dat je branch {{.selectedBranchName}} geforceerd wil verwijderen?",
+		DeleteBranchMessage:                 "Weet je zeker dat je branch '{{.selectedBranchName}}' wilt verwijderen?",
+		ForceDeleteBranchMessage:            "Weet je zeker dat je branch '{{.selectedBranchName}}' geforceerd wil verwijderen?",
 		LcRebaseBranch:                      "rebase branch",
 		CantRebaseOntoSelf:                  "Je kan niet een branch rebasen op zichzelf",
 		CantMergeBranchIntoItself:           "Je kan niet een branch in zichzelf mergen",
@@ -79,8 +79,7 @@ func dutchTranslationSet() TranslationSet {
 		Squash:                              "Squash",
 		LcPickCommit:                        "kies commit (wanneer midden in rebase)",
 		LcRevertCommit:                      "commit ongedaan maken",
-		OnlyRenameTopCommit:                 "Je kan alleen de bovenste commit hernoemen",
-		LcRenameCommit:                      "hernoem commit",
+		LcRewordCommit:                      "hernoem commit",
 		LcDeleteCommit:                      "verwijder commit",
 		LcMoveDownCommit:                    "verplaats commit 1 naar beneden",
 		LcMoveUpCommit:                      "verplaats commit 1 naar boven",
@@ -106,7 +105,6 @@ func dutchTranslationSet() TranslationSet {
 		SurePopStashEntry:                   "Weet je zeker dat je deze stash entry wil poppen?",
 		StashApply:                          "Stash toepassen",
 		SureApplyStashEntry:                 "Weet je zeker dat je deze stash entry wil toepassen?",
-		NoStashTo:                           "Geen stash voor {{.method}}",
 		NoTrackedStagedFilesStash:           "Je hebt geen tracked/staged bestanden om te laten stashen",
 		StashChanges:                        "Stash veranderingen",
 		NoChangedFiles:                      "Geen veranderde bestanden",
@@ -175,8 +173,8 @@ func dutchTranslationSet() TranslationSet {
 		ConflictsResolved:                   "alle merge conflicten zijn opgelost. Wilt je verder gaan?",
 		RebasingTitle:                       "Rebasen",
 		MergingTitle:                        "Mergen",
-		ConfirmRebase:                       "Weet je zeker dat je {{.checkedOutBranch}} op {{.selectedBranch}} wil rebasen?",
-		ConfirmMerge:                        "Weet je zeker dat je {{.selectedBranch}} in {{.checkedOutBranch}} wil mergen?",
+		ConfirmRebase:                       "Weet je zeker dat je '{{.checkedOutBranch}}' op '{{.selectedBranch}}' wil rebasen?",
+		ConfirmMerge:                        "Weet je zeker dat je '{{.selectedBranch}}' in '{{.checkedOutBranch}}' wil mergen?",
 		FwdNoUpstream:                       "Kan niet de branch vooruitspoelen zonder upstream",
 		FwdCommitsToPush:                    "Je kan niet vooruitspoelen als de branch geen nieuwe commits heeft",
 		ErrorOccurred:                       "Er is iets fout gegaan! Zou je hier een issue aan willen maken",
@@ -295,7 +293,7 @@ func dutchTranslationSet() TranslationSet {
 		SureCheckoutThisCommit:              "Weet je zeker dat je deze commit wil uitchecken?",
 		LcGitFlowOptions:                    "laat git-flow opties zien",
 		NotAGitFlowBranch:                   "Dit lijkt geen git flow branch te zijn",
-		NewGitFlowBranchPrompt:              "nieuwe {{.branchType}} naam:",
+		NewGitFlowBranchPrompt:              "nieuwe '{{.branchType}}' naam:",
 		IgnoreTracked:                       "Negeer tracked bestand",
 		IgnoreTrackedPrompt:                 "weet je zeker dat je een getracked bestand wil negeren?",
 		LcViewResetToUpstreamOptions:        "bekijk upstream reset opties",
